<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>BreakOutGap</name>
    <message>
        <location filename="../BreakOutGap.js" line="+53"/>
        <source>Choose line, arc or circle</source>
        <translation>線分、弧、円を選択して下さい</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Specify point</source>
        <translation>点を指定</translation>
    </message>
    <message>
        <location filename="../BreakOutGap.ui" line="+17"/>
        <source>Gap:</source>
        <translation>ギャップ:</translation>
    </message>
    <message>
        <location filename="../BreakOutGapInit.js" line="+2"/>
        <source>&amp;Break out Gap</source>
        <translation>隙間を分断</translation>
    </message>
</context>
</TS>
